@@ -26,6 +26,8 @@
 
 #include <Version.h>
 #include <cmake.h>
+// cmake.h include header must come first
+
 #include <iostream>
 #include <sstream>
 #include <string>
@@ -65,38 +67,32 @@ bool Version::is_valid() const { return major >= 0; }
 
 ////////////////////////////////////////////////////////////////////////////////
 bool Version::operator<(const Version &other) const {
-  return std::tie(major, minor, patch) <
-         std::tie(other.major, other.minor, other.patch);
+  return std::tie(major, minor, patch) < std::tie(other.major, other.minor, other.patch);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 bool Version::operator<=(const Version &other) const {
-  return std::tie(major, minor, patch) <=
-         std::tie(other.major, other.minor, other.patch);
+  return std::tie(major, minor, patch) <= std::tie(other.major, other.minor, other.patch);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 bool Version::operator>(const Version &other) const {
-  return std::tie(major, minor, patch) >
-         std::tie(other.major, other.minor, other.patch);
+  return std::tie(major, minor, patch) > std::tie(other.major, other.minor, other.patch);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 bool Version::operator>=(const Version &other) const {
-  return std::tie(major, minor, patch) >=
-         std::tie(other.major, other.minor, other.patch);
+  return std::tie(major, minor, patch) >= std::tie(other.major, other.minor, other.patch);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 bool Version::operator==(const Version &other) const {
-  return std::tie(major, minor, patch) ==
-         std::tie(other.major, other.minor, other.patch);
+  return std::tie(major, minor, patch) == std::tie(other.major, other.minor, other.patch);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 bool Version::operator!=(const Version &other) const {
-  return std::tie(major, minor, patch) !=
-         std::tie(other.major, other.minor, other.patch);
+  return std::tie(major, minor, patch) != std::tie(other.major, other.minor, other.patch);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
