@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2020, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2021, Tomas Babej, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -29,10 +29,9 @@
 
 #include <ColTypeDate.h>
 
-class ColumnModified : public ColumnTypeDate
-{
-public:
-  ColumnModified ();
+class ColumnModified : public ColumnTypeDate {
+ public:
+  ColumnModified();
 };
 
 #endif
