@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2020, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2021, Tomas Babej, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -31,16 +31,15 @@
 
 // This is 'string', and not 'duration' to force the value to be stored as a
 // raw duration, so that it can be reevaluated every time.
-class ColumnRecur : public ColumnTypeString
-{
-public:
-  ColumnRecur ();
-  void setStyle (const std::string&);
-  void measure (Task&, unsigned int&, unsigned int&);
-  void render (std::vector <std::string>&, Task&, int, Color&);
-  void modify (Task&, const std::string&);
+class ColumnRecur : public ColumnTypeString {
+ public:
+  ColumnRecur();
+  void setStyle(const std::string&);
+  void measure(Task&, unsigned int&, unsigned int&);
+  void render(std::vector<std::string>&, Task&, int, Color&);
+  void modify(Task&, const std::string&);
 
-private:
+ private:
 };
 
 #endif
