@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2020, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2021, Tomas Babej, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,24 +25,23 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+// cmake.h include header must come first
+
 #include <ColScheduled.h>
 
 ////////////////////////////////////////////////////////////////////////////////
-ColumnScheduled::ColumnScheduled ()
-{
-  _name  = "scheduled";
+ColumnScheduled::ColumnScheduled() {
+  _name = "scheduled";
   _label = "Scheduled";
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 // Overriden so that style <----> label are linked.
 // Note that you can not determine which gets called first.
-void ColumnScheduled::setStyle (const std::string& value)
-{
-  Column::setStyle (value);
+void ColumnScheduled::setStyle(const std::string& value) {
+  Column::setStyle(value);
 
-  if (_style == "countdown" && _label == "Scheduled")
-    _label = "Count";
+  if (_style == "countdown" && _label == "Scheduled") _label = "Count";
 }
 
 ////////////////////////////////////////////////////////////////////////////////
