@@ -33,7 +33,6 @@
 #include <Duration.h>
 #include <Filter.h>
 #include <format.h>
-#include <main.h>
 #include <math.h>
 #include <shared.h>
 #include <string.h>
@@ -767,6 +766,7 @@ CmdBurndownMonthly::CmdBurndownMonthly() {
   _read_only = true;
   _displays_id = false;
   _needs_gc = true;
+  _needs_recur_update = true;
   _uses_context = true;
   _accepts_filter = true;
   _accepts_modifications = false;
@@ -779,8 +779,6 @@ int CmdBurndownMonthly::execute(std::string& output) {
   int rc = 0;
 
   // Scan the pending tasks, applying any filter.
-  handleUntil();
-  handleRecurrence();
   Filter filter;
   std::vector<Task> filtered;
   filter.subset(filtered);
@@ -801,6 +799,7 @@ CmdBurndownWeekly::CmdBurndownWeekly() {
   _read_only = true;
   _displays_id = false;
   _needs_gc = true;
+  _needs_recur_update = true;
   _uses_context = true;
   _accepts_filter = true;
   _accepts_modifications = false;
@@ -813,8 +812,6 @@ int CmdBurndownWeekly::execute(std::string& output) {
   int rc = 0;
 
   // Scan the pending tasks, applying any filter.
-  handleUntil();
-  handleRecurrence();
   Filter filter;
   std::vector<Task> filtered;
   filter.subset(filtered);
@@ -835,6 +832,7 @@ CmdBurndownDaily::CmdBurndownDaily() {
   _read_only = true;
   _displays_id = false;
   _needs_gc = true;
+  _needs_recur_update = true;
   _uses_context = true;
   _accepts_filter = true;
   _accepts_modifications = false;
@@ -847,8 +845,6 @@ int CmdBurndownDaily::execute(std::string& output) {
   int rc = 0;
 
   // Scan the pending tasks, applying any filter.
-  handleUntil();
-  handleRecurrence();
   Filter filter;
   std::vector<Task> filtered;
   filter.subset(filtered);
