@@ -32,7 +32,6 @@
 #include <DOM.h>
 #include <Variant.h>
 #include <format.h>
-#include <main.h>
 #include <shared.h>
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -43,6 +42,7 @@ CmdGet::CmdGet() {
   _read_only = true;
   _displays_id = false;
   _needs_gc = false;
+  _needs_recur_update = false;
   _uses_context = false;
   _accepts_filter = false;
   _accepts_modifications = false;
