@@ -32,7 +32,7 @@
 #include <FS.h>
 #include <Table.h>
 #include <format.h>
-#include <main.h>
+#include <legacy.h>
 #include <util.h>
 
 #include <algorithm>
@@ -53,6 +53,7 @@ CmdShow::CmdShow() {
   _read_only = true;
   _displays_id = false;
   _needs_gc = false;
+  _needs_recur_update = false;
   _uses_context = false;
   _accepts_filter = false;
   _accepts_modifications = false;
