@@ -34,7 +34,6 @@
 #include <Filter.h>
 #include <Table.h>
 #include <format.h>
-#include <main.h>
 #include <stdlib.h>
 #include <util.h>
 
@@ -49,6 +48,7 @@ CmdStats::CmdStats() {
   _read_only = true;
   _displays_id = false;
   _needs_gc = true;
+  _needs_recur_update = false;
   _uses_context = true;
   _accepts_filter = true;
   _accepts_modifications = false;
