@@ -28,13 +28,18 @@
 #define INCLUDED_CMDUNDO
 
 #include <Command.h>
+#include <Operation.h>
 
 #include <string>
+#include <vector>
 
 class CmdUndo : public Command {
  public:
   CmdUndo();
-  int execute(std::string&);
+  int execute(std::string &);
+
+ private:
+  bool confirm_revert(const std::vector<Operation> &);
 };
 
 #endif
