@@ -25,15 +25,9 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-
-#include <algorithm>
 // cmake.h include header must come first
-
 #include <Context.h>
 
-#include <iterator>
-#include <unordered_set>
-#include <utility>
 #include <vector>
 
 ////////////////////////////////////////////////////////////////////////////////
