@@ -29,9 +29,8 @@
 
 #include <Context.h>
 #include <Datetime.h>
-#include <main.h>
+#include <rules.h>
 #include <shared.h>
-#include <stdlib.h>
 
 static std::map<std::string, Color> gsColor;
 static std::vector<std::string> gsPrecedence;
